@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.11 2005/01/13 16:15:48 chpe Exp $
+ *  $Id: extensions-manager-ui.c,v 1.12.2.1 2005/03/15 12:17:17 chpe Exp $
  */
 
 #include "config.h"
@@ -72,6 +72,7 @@ EphyDialogProperty properties [] =
 enum
 {
 	COL_INFO,	/* EphyExtensionInfo* */
+	COL_NAME,	/* Search column */
 	COL_TOGGLE,	/* enabled? */
 	COL_DISPLAY,	/* String representation */
 	N_COLUMNS
@@ -221,6 +222,7 @@ fill_list_store (EphyExtensionsManager *manager,
 
 		gtk_list_store_set (store, &iter,
 				    COL_INFO, info,
+				    COL_NAME, info->name,
 				    COL_TOGGLE, info->active,
 				    COL_DISPLAY, display,
 				    -1);
@@ -366,6 +368,7 @@ build_ui (ExtensionsManagerUI *dialog)
 
 	store = gtk_list_store_new (N_COLUMNS,
 				    G_TYPE_POINTER,
+				    G_TYPE_STRING,
 				    G_TYPE_BOOLEAN,
 				    G_TYPE_STRING);
 	fill_list_store (dialog->priv->manager, store);
@@ -374,6 +377,8 @@ build_ui (ExtensionsManagerUI *dialog)
 
 	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL (store));
 
+	gtk_tree_view_set_search_column (treeview, COL_NAME);
+
 	priv->model = GTK_TREE_MODEL (store);
 	g_object_unref (store);
 }
@@ -400,6 +405,7 @@ extension_added_cb (EphyExtensionsManager *manager,
 
 	gtk_list_store_set (store, &iter,
 			    COL_INFO, info,
+			    COL_NAME, info->name,
 			    COL_TOGGLE, info->active,
 			    COL_DISPLAY, display,
 			    -1);
@@ -436,7 +442,7 @@ extension_removed_cb (EphyExtensionsManager *manager,
 static void
 extensions_manager_ui_init (ExtensionsManagerUI *dialog)
 {		
-	LOG ("ExtensionsManagerUI initializing")
+	LOG ("ExtensionsManagerUI initializing");
 
 	dialog->priv = EXTENSIONS_MANAGER_UI_GET_PRIVATE (dialog);
 
@@ -467,7 +473,7 @@ extensions_manager_ui_finalize (GObject *object)
 {
 	ExtensionsManagerUI *dialog = EXTENSIONS_MANAGER_UI (object);
 
-	LOG ("ExtensionsManagerUI finalising")
+	LOG ("ExtensionsManagerUI finalising");
 
 	g_signal_handler_disconnect (G_OBJECT (dialog->priv->manager),
 				     dialog->priv->changed_signal);
