@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.15 2004/12/17 19:10:19 adamh Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.22 2005/02/20 22:16:27 jframeau Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-gestures-extension.h"
 #include "ephy-gesture.h"
@@ -116,13 +114,13 @@ load_one_gesture (EphyGesturesExtension *extension,
 
 	for (child = node->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, "sequence"))
+		if (xmlStrEqual (child->name, (const xmlChar*) "sequence"))
 		{
 			s = xmlNodeGetContent (child);
 
 			sequences = g_slist_prepend (sequences, s);
 		}
-		else if (xmlStrEqual (child->name, "action"))
+		else if (xmlStrEqual (child->name, (const xmlChar*) "action"))
 		{
 			if (action == NULL)
 			{
@@ -145,7 +143,7 @@ load_one_gesture (EphyGesturesExtension *extension,
 	{
 		g_hash_table_insert (extension->priv->gestures,
 				     g_strdup (l->data),
-				     g_strdup (action));
+				     g_strdup ((char*)action));
 		xmlFree (l->data);
 	}
 
@@ -175,7 +173,7 @@ load_gestures (EphyGesturesExtension *extension,
 	}
 
 	root = xmlDocGetRootElement (doc);
-	if (root == NULL || strcmp (root->name, EPHY_GESTURES_XML_ROOT) != 0)
+	if (root == NULL || strcmp ((char*)root->name, EPHY_GESTURES_XML_ROOT) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format '%s'"
 		           "(expected " EPHY_GESTURES_XML_ROOT ")\n",
@@ -183,8 +181,8 @@ load_gestures (EphyGesturesExtension *extension,
 		goto out;
 	}
 
-	tmp = xmlGetProp (root, "version");
-	if (tmp  == NULL || strcmp (tmp, EPHY_GESTURES_XML_VERSION) != 0)
+	tmp = xmlGetProp (root, (const xmlChar*) "version");
+	if (tmp  == NULL || strcmp ((char*) tmp, (char*) EPHY_GESTURES_XML_VERSION) != 0)
 	{
 		g_warning ("Gestures definitions file %s has wrong format version %s"
 			   "(expected " EPHY_GESTURES_XML_VERSION ")\n",
@@ -194,7 +192,7 @@ load_gestures (EphyGesturesExtension *extension,
 
 	for (child = root->children; child != NULL; child = child->next)
 	{
-		if (xmlStrEqual (child->name, "gesture"))
+		if (xmlStrEqual (child->name, (const xmlChar*) "gesture"))
 		{
 			load_one_gesture (extension, child);
 		}
@@ -245,7 +243,7 @@ gesture_performed_cb (EphyGesture *gesture,
 	EphyWindow *window;
 	const char *path;
 
-	LOG ("Gesture: sequence '%s'", sequence)
+	LOG ("Gesture: sequence '%s'", sequence);
 
 	path = g_hash_table_lookup (extension->priv->gestures, sequence);
 	if (path == NULL)
@@ -262,7 +260,6 @@ gesture_performed_cb (EphyGesture *gesture,
 		EphyEmbed *embed;
 		EphyEmbedEvent *event;
 		gint handled = FALSE;
-		guint type;
 
 		embed = ephy_window_get_active_embed (window);
 		g_return_if_fail (EPHY_IS_EMBED (embed));
@@ -270,16 +267,8 @@ gesture_performed_cb (EphyGesture *gesture,
 		event = ephy_gesture_get_event (gesture);
 		g_return_if_fail (EPHY_IS_EMBED_EVENT (event));
 
-		type = ephy_embed_event_get_event_type (event);
-
 		g_signal_emit_by_name (embed, "ge_dom_mouse_click", event,
 				       &handled);
-
-		if (handled == FALSE && type == EPHY_EMBED_EVENT_MOUSE_BUTTON3)
-		{
-			g_signal_emit_by_name (embed, "ge_context_menu",
-					       event, &handled);
-		}
 	}
 	else
 	{
@@ -305,25 +294,33 @@ dom_mouse_down_cb (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   EphyGesturesExtension *extension)
 {
-        EmbedEventContext context;
-	EphyEmbedEventType type;
+        EphyEmbedEventContext context;
+	guint button;
 	gint handled = FALSE;
+	EphyTab *tab;
+	EphyWindow *window;
+	GtkWidget *toplevel;
+	gboolean ppv_mode;
 
-	type = ephy_embed_event_get_event_type (event);
+	tab = ephy_tab_for_embed (embed);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
+		
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+	g_return_val_if_fail (toplevel != NULL, handled);
+
+	/* disable gestures while print preview mode */
+	window = EPHY_WINDOW (toplevel);
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), handled);
+
+	g_object_get (window, "print-preview-mode", &ppv_mode, NULL);
+	if (ppv_mode) return handled;
+
+	button = ephy_embed_event_get_button (event);
         context = ephy_embed_event_get_context (event);
 
-	if (type == EPHY_EMBED_EVENT_MOUSE_BUTTON2 &&
-            !(context & EMBED_CONTEXT_INPUT))
+	if (button == 2 && !(context & EPHY_EMBED_CONTEXT_INPUT))
 	{
 		EphyGesture *gesture;
-		GtkWidget *toplevel;
-		EphyTab *tab;
-
-		tab = ephy_tab_for_embed (embed);
-		g_return_val_if_fail (EPHY_IS_TAB (tab), handled);
-
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
-		g_return_val_if_fail (toplevel != NULL, handled);
 
 		gesture = ephy_gesture_new (toplevel, event);
 
@@ -346,7 +343,7 @@ impl_attach_tab (EphyExtension *extension,
 {
 	EphyEmbed *embed;
 
-	LOG ("Attach tab")
+	LOG ("Attach tab");
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
@@ -364,7 +361,7 @@ impl_detach_tab (EphyExtension *extension,
 {
 	EphyEmbed *embed;
 
-	LOG ("Detach tab")
+	LOG ("Detach tab");
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
