@@ -15,19 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.1.2.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.12 2005/01/28 22:30:33 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "smart-bookmarks-extension.h"
-#include "smart-bookmarks-prefs-ui.h"
-#include "smart-bookmarks-prefs.h"
 #include "mozilla-selection.h"
-#include "eel-gconf-extensions.h"
-#include "ephy-debug.h"
 
 #include <epiphany/ephy-extension.h>
 #include <epiphany/ephy-embed.h>
@@ -36,17 +30,23 @@
 #include <epiphany/ephy-session.h>
 #include <epiphany/ephy-node.h>
 #include <epiphany/ephy-bookmarks.h>
-#include "ephy-string.h"
+
+#include "eel-gconf-extensions.h"
+#include "ephy-debug.h"
 
 #include <gmodule.h>
 #include <gtk/gtkaction.h>
 #include <gtk/gtkactiongroup.h>
 #include <gtk/gtkuimanager.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkmenuitem.h>
 
 #include <glib/gi18n-lib.h>
 
 #include <string.h>
 
+#define CONF_OPEN_IN_TAB  "/apps/epiphany/extensions/smart-bookmarks/dictionarysearch/open_in_tab"
+
 #define SMART_BOOKMARKS_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), TYPE_SMART_BOOKMARKS_EXTENSION, SmartBookmarksExtensionPrivate))
 
 #define SMB_ACTION		"SmbExt%x"
@@ -55,6 +55,7 @@
 #define GDICT_ACTION		"SmbExtGDict"
 #define NODE_ID_KEY		"EphyNodeId"
 #define WINDOW_DATA_KEY		"SmartBookmarksWindowData"
+#define LABEL_WIDTH_CHARS	32
 
 struct SmartBookmarksExtensionPrivate
 {
@@ -218,7 +219,7 @@ context_menu_cb (EphyEmbed *embed,
 		 EphyEmbedEvent *event,
 		 EphyWindow *window)
 {
-	gboolean can_copy, use_gdict;
+	gboolean can_copy;
 	GtkAction  *action;
 	WindowData *data;
 
@@ -234,13 +235,6 @@ context_menu_cb (EphyEmbed *embed,
 
 	g_object_set(action, "sensitive", can_copy, "visible", can_copy, NULL);
 
-	/* Display or not Gnome Dictionary entry */
-	action = gtk_action_group_get_action (data->action_group, GDICT_ACTION);
-	g_return_val_if_fail (action != NULL, FALSE);
-
-	use_gdict = eel_gconf_get_boolean (CONF_USE_GDICT);
-	g_object_set(action, "sensitive", use_gdict, "visible", use_gdict, NULL);
-
 	return FALSE;
 }
 
@@ -291,7 +285,7 @@ rebuild_ui (WindowData *data)
 	char verb[SMB_ACTION_LENGTH];
 	int i;
 
-	LOG ("Rebuilding UI")
+	LOG ("Rebuilding UI");
 
 	/* clean UI */
 	if (data->ui_id != 0)
@@ -302,11 +296,6 @@ rebuild_ui (WindowData *data)
 
 	data->ui_id = ui_id = gtk_ui_manager_new_merge_id (manager);
 
-	/* Add prefs UI */
-	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
-			       "SmartBookmarksPrefsItem", "SmartBookmarksPrefs",
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
-
 	/* Add bookmarks to popup context (normal document) */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyDocumentPopup",
 			       "SmbExtSep0", NULL,
@@ -314,6 +303,12 @@ rebuild_ui (WindowData *data)
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyDocumentPopup",
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
+			       "SmbExtSep0", NULL,
+			       GTK_UI_MANAGER_SEPARATOR, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenDocumentPopup",
+			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
+			       GTK_UI_MANAGER_MENU, FALSE);
 
 	/* Add bookmarks to popup context (framed document) */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
@@ -322,6 +317,12 @@ rebuild_ui (WindowData *data)
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
+			       "SmbExtSep0", NULL,
+			       GTK_UI_MANAGER_SEPARATOR, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
+			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
+			       GTK_UI_MANAGER_MENU, FALSE);
 
 	/* get smart bookmarks and sort them */
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
@@ -349,6 +350,14 @@ rebuild_ui (WindowData *data)
 				       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
+		gtk_ui_manager_add_ui (manager, ui_id,
+				       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
+				       verb, verb,
+				       GTK_UI_MANAGER_MENUITEM, FALSE);
+		gtk_ui_manager_add_ui (manager, ui_id,
+				       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
+				       verb, verb,
+				       GTK_UI_MANAGER_MENUITEM, FALSE);
 	}
 
 	g_list_free (bmks);
@@ -358,10 +367,18 @@ rebuild_ui (WindowData *data)
 			       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "IDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id,
+			       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
+			       GDICT_ACTION "FSIDP", GDICT_ACTION,
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id,
 			       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
 			       GDICT_ACTION "IFDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id,
+			       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
+			       GDICT_ACTION "FSIFDP", GDICT_ACTION,
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 
 	gtk_ui_manager_ensure_update (manager);
 }
@@ -384,17 +401,10 @@ static void
 sync_bookmark_properties (GtkAction *action,
 			  EphyNode *bmk)
 {
-        const char *tmp;
-        char *title;
-
-        tmp = ephy_node_get_property_string (bmk, EPHY_NODE_BMK_PROP_TITLE);
-        title = ephy_string_double_underscores (tmp);
-
-        g_object_set (action,
-                      "label", title,
-                      NULL);
-
-        g_free (title);
+	const char *title;
+	
+	title = ephy_node_get_property_string (bmk, EPHY_NODE_BMK_PROP_TITLE);
+	g_object_set (action, "label", title, NULL);
 }
 
 static void
@@ -482,7 +492,7 @@ smart_bookmark_added_cb (EphyNode *keywords,
 			 EphyNode *bmk,
 			 SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks added")
+	LOG ("SmartBookmarksExtension smart bookmarks added");
 
 	foreach_window ((GFunc) add_bookmark_to_window, bmk);
 }
@@ -493,7 +503,7 @@ smart_bookmark_removed_cb (EphyNode *keywords,
 			   guint old_index,
 			   SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks removed")
+	LOG ("SmartBookmarksExtension smart bookmarks removed");
 
 	foreach_window ((GFunc) remove_bookmark_from_window, bmk);
 }
@@ -504,7 +514,7 @@ smart_bookmark_changed_cb (EphyNode *node,
 			   guint property_id,
 			   SmartBookmarksExtension *extension)
 {
-	LOG ("SmartBookmarksExtension smart bookmarks changed")
+	LOG ("SmartBookmarksExtension smart bookmarks changed");
 
 	if (property_id == EPHY_NODE_BMK_PROP_TITLE)
 	{
@@ -513,9 +523,9 @@ smart_bookmark_changed_cb (EphyNode *node,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphyWindow *window)
+impl_attach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
@@ -527,9 +537,9 @@ tab_added_cb (GtkWidget *notebook,
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphyWindow *window)
+impl_detach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
@@ -540,6 +550,27 @@ tab_removed_cb (GtkWidget *notebook,
 		(embed, G_CALLBACK (context_menu_cb), window);
 }
 
+static void
+connect_proxy_cb (GtkActionGroup *action_group,
+                  GtkAction *action,
+                  GtkWidget *proxy)
+{
+	/* If NODE_ID_KEY has NULL data, we have the main menu entry, or the
+	 * context menu main entry. Allow underscores for these.
+	 */
+	if (GTK_IS_MENU_ITEM (proxy) &&
+	    g_object_get_data (G_OBJECT (action),NODE_ID_KEY) != NULL)
+	{
+		GtkLabel *label;
+	
+		label = (GtkLabel *) ((GtkBin *) proxy)->child;
+
+		gtk_label_set_use_underline (label, FALSE);
+		gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+		gtk_label_set_max_width_chars (label, LABEL_WIDTH_CHARS);
+	}
+}
+
 static GtkActionEntry action_entries [] =
 {
 	{ LOOKUP_ACTION,
@@ -556,36 +587,20 @@ static GtkActionEntry action_entries [] =
 	  NULL,
 	  G_CALLBACK (search_gnome_dict_cb)
 	},
-	{ "SmartBookmarksPrefs",
-	  NULL,
-	  N_("Loo_k-Up Preferences"),
-	  NULL, /* shortcut key */
-	  N_("Look up your selection"),
-	  G_CALLBACK (smart_bookmarks_show_prefs_ui_cb)
-	}
 };
-static const guint n_action_entries = G_N_ELEMENTS (action_entries);
 
 static void
 impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 	GtkActionGroup *action_group;
-	GtkWidget *notebook;
 	WindowData *data;
 	EphyBookmarks *bookmarks;
 	GPtrArray *children;
 	EphyNode *smart_bmks, *bmk;
 	int i;
 
-	LOG ("SmartBookmarksExtension attach_window %p", window)
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_connect_after (notebook, "tab_added",
-			G_CALLBACK (tab_added_cb), window);
-	g_signal_connect_after (notebook, "tab_removed",
-			G_CALLBACK (tab_removed_cb), window);
+	LOG ("SmartBookmarksExtension attach_window %p", window);
 
 	/* Attach ui infos to the window */
 	data = g_new0 (WindowData, 1);
@@ -594,11 +609,13 @@ impl_attach_window (EphyExtension *ext,
 
 	/* Create new action group for this extension */
 	action_group = gtk_action_group_new ("SmbExtActions");
+	g_signal_connect (action_group, "connect-proxy",
+			  G_CALLBACK (connect_proxy_cb), NULL);
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, action_entries,
-				      n_action_entries, window);
+				      G_N_ELEMENTS (action_entries), window);
 
-	data->manager = GTK_UI_MANAGER (window->ui_merge);
+	data->manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 	data->action_group = action_group;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
@@ -613,9 +630,9 @@ impl_attach_window (EphyExtension *ext,
 	}
 
 	/* Action group completed */
-	gtk_ui_manager_insert_action_group (data->manager, action_group, 0),
+	gtk_ui_manager_insert_action_group (data->manager, action_group, -1);
 	g_object_unref (action_group);
-	
+
 	/* now add the UI to the window */
 	rebuild_ui (data);
 }
@@ -624,16 +641,18 @@ static void
 impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
-	GtkWidget *notebook;
+	WindowData *data;
 
-	LOG ("SmartBookmarksExtension detach_window")
+	LOG ("SmartBookmarksExtension detach_window");
 
-	notebook = ephy_window_get_notebook (window);
+	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	g_return_if_fail (data != NULL);
 
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), window);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), window);
+	gtk_ui_manager_remove_ui (data->manager, data->ui_id);
+	gtk_ui_manager_ensure_update (data->manager);
+	gtk_ui_manager_remove_action_group (data->manager, data->action_group);
+
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
 }
 
 static void
@@ -641,6 +660,8 @@ smart_bookmarks_extension_iface_init (EphyExtensionIface *iface)
 {
 	iface->attach_window = impl_attach_window;
 	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
 }
 
 static void
@@ -649,7 +670,7 @@ smart_bookmarks_extension_init (SmartBookmarksExtension *extension)
 	EphyBookmarks *bookmarks;
 	EphyNode *smart_bmks;
 
-	LOG ("SmartBookmarksExtension initialising")
+	LOG ("SmartBookmarksExtension initialising");
 
 	extension->priv = SMART_BOOKMARKS_EXTENSION_GET_PRIVATE (extension);
 
@@ -671,20 +692,6 @@ smart_bookmarks_extension_init (SmartBookmarksExtension *extension)
 			(smart_bmks, EPHY_NODE_CHILD_CHANGED,
 			 (EphyNodeCallback) smart_bookmark_changed_cb,
 			 G_OBJECT (extension));
-
-	eel_gconf_monitor_add (CONF_DIR);
-}
-
-static void
-smart_bookmarks_extension_finalize (GObject *object)
-{
-//	SmartBookmarksExtension *extension = SMART_BOOKMARKS_EXTENSION (object);
-
-	LOG ("SmartBookmarksExtension finalising")
-
-	eel_gconf_monitor_remove (CONF_DIR);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static void
@@ -694,7 +701,5 @@ smart_bookmarks_extension_class_init (SmartBookmarksExtensionClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	object_class->finalize = smart_bookmarks_extension_finalize;
-
 	g_type_class_add_private (object_class, sizeof (SmartBookmarksExtensionPrivate));
 }
